<!DOCTYPE html><htmllang="en"><head><metacharset="utf-8"><metaname="viewport"content="width=device-width, initial-scale=1.0"><metaname="generator"content="rustdoc"><metaname="description"content="Error returned when a Syn parser cannot parse the input tokens."><metaname="keywords"content="rust, rustlang, rust-lang, Error"><title>Error in syn - Rust</title><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/SourceSerif4-Regular-1f7d512b176f0f72.ttf.woff2"><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/FiraSans-Regular-018c141bf0843ffd.woff2"><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/FiraSans-Medium-8f9a781e4970d388.woff2"><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/SourceCodePro-Regular-562dcc5011b6de7d.ttf.woff2"><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/SourceSerif4-Bold-124a1ca42af929b6.ttf.woff2"><linkrel="preload"as="font"type="font/woff2"crossoriginhref="../static.files/SourceCodePro-Semibold-d899c5a5c4aeb14a.ttf.woff2"><linkrel="stylesheet"href="../static.files/normalize-76eba96aa4d2e634.css"><linkrel="stylesheet"href="../static.files/rustdoc-6827029ac823cab7.css"id="mainThemeStyle"><linkrel="stylesheet"id="themeStyle"href="../static.files/light-ebce58d0a40c3431.css"><linkrel="stylesheet"disabledhref="../static.files/dark-f23faae4a2daf9a6.css"><linkrel="stylesheet"disabledhref="../static.files/ayu-8af5e100b21cd173.css"><scriptid="default-settings"></script><scriptsrc="../static.files/storage-d43fa987303ecbbb.js"></script><scriptdefersrc="sidebar-items.js"></script><scriptdefersrc="../static.files/main-c55e1eb52e1886b4.js"></script><noscript><linkrel="stylesheet"href="../static.files/noscript-13285aec31fa243e.css"></noscript><linkrel="alternate icon"type="image/png"href="../static.files/favicon-16x16-8b506e7a72182f1c.png"><linkrel="alternate icon"type="image/png"href="../static.files/favicon-32x32-422f7d1d52889060.png"><linkrel="icon"type="image/svg+xml"href="../static.files/favicon-2c020d218678b618.svg"></head><bodyclass="rustdoc struct"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><navclass="mobile-topbar"><buttonclass="sidebar-menu-toggle">☰</button><aclass="sidebar-logo"href="../syn/index.html"><divclass="logo-container"><imgclass="rust-logo"src="../static.files/rust-logo-151179464ae7ed46.svg"alt="logo"></div></a><h2></h2></nav><navclass="sidebar"><aclass="sidebar-logo"href="../syn/index.html"><divclass="logo-container"><imgclass="rust-logo"src="../static.files/rust-logo-151179464ae7ed46.svg"alt="logo"></div></a><h2class="location"><ahref="#">Error</a></h2><divclass="sidebar-elems"><section><h3><ahref="#implementations">Methods</a></h3><ulclass="block"><li><ahref="#method.combine">combine</a></li><li><ahref="#method.into_compile_error">into_compile_error</a></li><li><ahref="#method.new">new</a></li><li><ahref="#method.new_spanned">new_spanned</a></li><li><ahref="#method.span">span</a></li><li><ahref="#method.to_compile_error">to_compile_error</a></li></ul><h3><ahref="#trait-implementations">Trait Implementations</a></h3><ulclass="block"><li><ahref="#impl-Clone-for-Error">Clone</a></li><li><ahref="#impl-Debug-for-Error">Debug</a></li><li><ahref="#impl-Display-for-Error">Display</a></li><li><ahref="#impl-Error-for-Error">Error</a></li><li><ahref="#impl-Extend%3CError%3E-for-Error">Extend<Error></a></li><li><ahref="#impl-From%3CLexError%3E-for-Error">From<LexError></a></li><li><ahref="#impl-IntoIterator-for-%26%27a%20Error">IntoIterator</a></li><li><ahref="#impl-IntoIterator-for-Error">IntoIterator</a></li></ul><h3><ahref="#synthetic-implementations">Auto Trait Implementations</a></h3><ulclass="block"><li><ahref="#impl-RefUnwindSafe-for-Error">RefUnwindSafe</a></li><li><ahref="#impl-Send-for-Error">Send</a></li><li><ahref="#impl-Sync-for-Error"
<h2id="error-reporting-in-proc-macros"><ahref="#error-reporting-in-proc-macros">Error reporting in proc macros</a></h2>
<ahref="https://doc.rust-lang.org/1.67.0/core/macro.compile_error.html"><code>compile_error!</code></a> in the generated code. This produces a better diagnostic
<ahref="parse/struct.Error.html#method.to_compile_error"><code>.to_compile_error()</code></a> or <ahref="parse/struct.Error.html#method.into_compile_error"><code>.into_compile_error()</code></a> methods can be used to
perform an explicit conversion to <code>compile_error!</code>.</p>
</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.new_spanned"class="method has-srclink"><aclass="srclink rightside"href="../src/syn/error.rs.html#164-179">source</a><h4class="code-header">pub fn <ahref="#method.new_spanned"class="fn">new_spanned</a><T: <aclass="trait"href="../quote/to_tokens/trait.ToTokens.html"title="trait quote::to_tokens::ToTokens">ToTokens</a>, U: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a>>(tokens: T, message: U) -> Self</h4></section></summary><divclass="docblock"><p>Creates an error with the specified message spanning the given syntax
</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_compile_error"class="method has-srclink"><aclass="srclink rightside"href="../src/syn/error.rs.html#205-210">source</a><h4class="code-header">pub fn <ahref="#method.to_compile_error"class="fn">to_compile_error</a>(&self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a></h4></section></summary><divclass="docblock"><p>Render the error as an invocation of <ahref="https://doc.rust-lang.org/1.67.0/core/macro.compile_error.html"><code>compile_error!</code></a>.</p>
<p>The <ahref="macro.parse_macro_input.html"><code>parse_macro_input!</code></a> macro provides a convenient way to invoke
</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.into_compile_error"class="method has-srclink"><aclass="srclink rightside"href="../src/syn/error.rs.html#244-246">source</a><h4class="code-header">pub fn <ahref="#method.into_compile_error"class="fn">into_compile_error</a>(self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a></h4></section></summary><divclass="docblock"><p>Render the error as an invocation of <ahref="https://doc.rust-lang.org/1.67.0/core/macro.compile_error.html"><code>compile_error!</code></a>.</p>
</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.combine"class="method has-srclink"><aclass="srclink rightside"href="../src/syn/error.rs.html#250-252">source</a><h4class="code-header">pub fn <ahref="#method.combine"class="fn">combine</a>(&mut self, another: <aclass="struct"href="parse/struct.Error.html"title="struct syn::parse::Error">Error</a>)</h4></section></summary><divclass="docblock"><p>Add another error message to self such that when <code>to_compile_error()</code> is
<p>That is, this conversion is whatever the implementation of
<code><ahref="https://doc.rust-lang.org/1.67.0/core/convert/trait.From.html"title="From">From</a><T> for U</code> chooses to do.</p>
</div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-Provider-for-Error"class="impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/core/error.rs.html#197">source</a><ahref="#impl-Provider-for-Error"class="anchor"></a><h3class="code-header">impl<E><aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/any/trait.Provider.html"title="trait core::any::Provider">Provider</a> for E<spanclass="where fmt-newline">where<br> E: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/error/trait.Error.html"title="trait core::error::Error">Error</a> + ?<aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.provide-1"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/core/error.rs.html#201">source</a><ahref="#method.provide-1"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/core/any/trait.Provider.html#tymethod.provide"class="fn">provide</a><'a>(&'a self, demand: &mut <aclass="struct"href="https://doc.rust-lang.org/1.67.0/core/any/struct.Demand.html"title="struct core::any::Demand">Demand</a><'a>)</h4></section></summary><spanclass="item-info"><divclass="stab unstable"><spanclass="emoji">🔬</span><span>This is a nightly-only experimental API. (<code>provide_any</code>)</span></div></span><divclass='docblock'>Data providers should implement this method to provide <em>all</em> values they are able to
provide by using <code>demand</code>. <ahref="https://doc.rust-lang.org/1.67.0/core/any/trait.Provider.html#tymethod.provide">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-ToOwned-for-Error"class="impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#82">source</a><ahref="#impl-ToOwned-for-Error"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html"title="trait alloc::borrow::ToOwned">ToOwned</a> for T<spanclass="where fmt-newline">where<br> T: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle"open><summary><sectionid="associatedtype.Owned"class="associatedtype trait-impl has-srclink"><ahref="#associatedtype.Owned"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#associatedtype.Owned"class="associatedtype">Owned</a> = T</h4></section></summary><divclass='docblock'>The resulting type after obtaining ownership.</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_owned"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#87">source</a><ahref="#method.to_owned"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned"class="fn">to_owned</a>(&self) -> T</h4></section></summary><divclass='docblock'>Creates owned data from borrowed data, usually by cloning. <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.clone_into"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#91">source</a><ahref="#method.clone_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#method.clone_into"class="fn">clone_into</a>(&self, target: <aclass="primitive"href="https://doc.rust-lang.org/1.67.0/std/primitive.reference.html">&mut </a>T)</h4></section></summary><divclass='docblock'>Uses borrowed data to replace owned data, usually by cloning. <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#method.clone_into">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-ToString-for-Error"class="impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/string.rs.html#2526">source</a><ahref="#impl-ToString-for-Error"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.67.0/alloc/string/trait.ToString.html"title="trait alloc::string::ToString">ToString</a> for T<spanclass="where fmt-newline">where<br> T: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/fmt/trait.Display.html"title="trait core::fmt::Display">Display</a> + ?<aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_string"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/string.rs.html#2532">source</a><ahref="#method.to_string"class="anchor"></a><h4class="code-header">default fn <ahref="https://doc.rust-lang.org/1.67.0/alloc/string/trait.ToString.html#tymethod.to_string"cl